@@ -37,10 +37,11 @@ theme_cowplot <- function(font_size = 14, font_family = "", line_size = .5) {
         margin = ggplot2::margin(r = small_size / 2, l = small_size / 4),
       ),
       axis.ticks        = element_line(colour = "black", size = line_size),
-      axis.line.x       = element_line(colour = "black", size = line_size),
-      axis.line.y       = element_line(colour = "black", size = line_size),
+      axis.line         = element_line(colour = "black", size = line_size),
+      # the following two lines are not needed for ggplot2 2.2.0 or later
+      axis.line.x         = element_line(colour = "black", size = line_size),
+      axis.line.y         = element_line(colour = "black", size = line_size),
       legend.key        = element_blank(),
-      legend.margin     = grid::unit(0.1, "cm"),
       legend.key.size   = grid::unit(1, "lines"),
       legend.text       = element_text(size = rel(small_rel)),
       #    legend.position   = c(-0.03, 1.05),
@@ -54,43 +55,28 @@ theme_cowplot <- function(font_size = 14, font_family = "", line_size = .5) {
       plot.background   = element_blank(),
       plot.title        = element_text(face = "bold",
                                        size = font_size,
-                                       margin = ggplot2::margin(b = half_line))
+                                       margin = ggplot2::margin(b = half_line)),
+
+      complete = TRUE
     )
 }
 
 
 #' Create a completely empty theme
 #'
-#' The theme created by this function shows nothing but the plot panel. Unfortunately,
-#' due to ggplot2 peculiarities, a little bit of padding remains to the left and bottom of
-#' the panel. This can be removed by adding \code{labs(x = NULL, y = NULL)} to the plot, see examples.
+#' The theme created by this function shows nothing but the plot panel. Since ggplot2 now
+#' provides \code{theme_void}, which serves the same purpose, this function is now just a
+#' wrapper around \code{theme_void}.
 #' @param base_size Overall font size. Default is 14.
 #' @param base_family Base font family.
 #' @return The theme.
 #' @examples
-#' # plot with small amount of remaining padding
 #' qplot(1:10, (1:10)^2) + theme_nothing()
-#' # remaining padding removed
-#' qplot(1:10, (1:10)^2) + theme_nothing() + labs(x = NULL, y = NULL)
 #' @export
-theme_nothing <- function(base_size = 12, base_family = ""){
-  theme_grey(base_size = base_size, base_family = base_family) %+replace%
-    theme(
-      rect              = element_rect(fill = "transparent", colour = NA, color = NA, size = 0, linetype = 0),
-      line              = element_blank(),
-      text              = element_blank(),
-      title             = element_blank(),
-      # to debug, uncomment next line
-      #plot.background   = element_rect(colour = "blue", fill = "cyan"),
-      panel.background  = element_blank(),
-      axis.ticks.length = grid::unit(0, "lines"),
-      legend.position   = "none",
-      panel.margin      = grid::unit(c(0, 0, 0, 0), "lines"),
-      plot.margin       = grid::unit(c(0, 0, 0, 0), "lines")
-    )
+theme_nothing <- function(base_size = 14, base_family = ""){
+  theme_void(base_size = base_size, base_family = base_family)
 }
 
-
 #' Add/modify/remove the background grid in a ggplot2 plot
 #'
 #' This function provides a simple way to modify the background grid in ggplot2. It
